==> ejc-guarantee-impl-3.0.0-20230419.062954-17-sources.jar: com/ejianc/business/guarantee/contract/bean/FinanceEntity.java <==
package com.ejianc.business.guarantee.contract.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 合同财务确认信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_guarantee_contract_finance")
public class FinanceEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="finance_remark")
    private String financeRemark; // 备注
    @TableField(value="finance_mny")
    private BigDecimal financeMny; // 保费金额
    @TableField(value="finance_receive")
    private Integer financeReceive; // 保费是否到账(1-是 2-否)
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="finance_return_mny")
    private BigDecimal financeReturnMny; // 反担保金额
    @TableField(value="finance_return_receive")
    private Integer financeReturnReceive; // 反担保金额是否到账(1-是 2-否)
    



    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getFinanceRemark() {
        return financeRemark;
    }

    public void setFinanceRemark(String financeRemark) {
        this.financeRemark = financeRemark;
    }

    public BigDecimal getFinanceMny() {
        return financeMny;
    }

    public void setFinanceMny(BigDecimal financeMny) {
        this.financeMny = financeMny;
    }
    public Integer getFinanceReceive() {
        return financeReceive;
    }

    public void setFinanceReceive(Integer financeReceive) {
        this.financeReceive = financeReceive;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public BigDecimal getFinanceReturnMny() {
        return financeReturnMny;
    }

    public void setFinanceReturnMny(BigDecimal financeReturnMny) {
        this.financeReturnMny = financeReturnMny;
    }
    public Integer getFinanceReturnReceive() {
        return financeReturnReceive;
    }

    public void setFinanceReturnReceive(Integer financeReturnReceive) {
        this.financeReturnReceive = financeReturnReceive;
    }

}

==> ejc-guarantee-impl-3.0.0-20231218.083246-53-sources.jar: com/ejianc/business/guarantee/contract/bean/FinanceEntity.java <==
package com.ejianc.business.guarantee.contract.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 合同财务确认信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_guarantee_contract_finance")
public class FinanceEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="finance_remark")
    private String financeRemark; // 备注
    @TableField(value="finance_mny")
    private BigDecimal financeMny; // 保费金额
    @TableField(value="finance_receive")
    private Integer financeReceive; // 保费是否到账(1-是 2-否)
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="finance_return_mny")
    private BigDecimal financeReturnMny; // 反担保金额
    @TableField(value="finance_return_receive")
    private Integer financeReturnReceive; // 反担保金额是否到账(1-是 2-否)
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getFinanceRemark() {
        return financeRemark;
    }

    public void setFinanceRemark(String financeRemark) {
        this.financeRemark = financeRemark;
    }

    public BigDecimal getFinanceMny() {
        return financeMny;
    }

    public void setFinanceMny(BigDecimal financeMny) {
        this.financeMny = financeMny;
    }
    public Integer getFinanceReceive() {
        return financeReceive;
    }

    public void setFinanceReceive(Integer financeReceive) {
        this.financeReceive = financeReceive;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public BigDecimal getFinanceReturnMny() {
        return financeReturnMny;
    }

    public void setFinanceReturnMny(BigDecimal financeReturnMny) {
        this.financeReturnMny = financeReturnMny;
    }
    public Integer getFinanceReturnReceive() {
        return financeReturnReceive;
    }

    public void setFinanceReturnReceive(Integer financeReturnReceive) {
        this.financeReturnReceive = financeReturnReceive;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
}
